@@ -38,7 +38,6 @@ class MyResourceProtector(ResourceProtector):
         :raise: UnsupportedTokenTypeError
         """
         auth = request.headers.get('Authorization')
-        print(self.require_token, file=sys.stderr)
         if not auth and self.require_token:
             raise MissingAuthorizationError(self._default_auth_type, self._default_realm)
         elif not auth:
@@ -148,8 +147,6 @@ class JWTValidator(BearerTokenValidator, ABC):
         self.require_token = require_token
 
     def authenticate_token(self, token_string):
-        print(self.static_jwt, file=sys.stderr)
-        print(self.require_token, file=sys.stderr)
         if not self.require_token and self.static_jwt is not False:
             token_string = self.static_jwt
         elif self.require_token is True and self.static_jwt is not False and token_string != self.static_jwt:
